%%% writeGoals
%%%		Action: write goals in the output files

writeGoals:-
		findall((F,N),numberOfGoals(F,N),LFN),
		catch(make_directory('Goals'),_,true),
		writeGoalsListOfFiles(LFN),
		catch(make_directory('Runs'),_,true).

%%% writeGoalsListOfFiles(in LFN)
%%%		LFN: a list of pairs (F,N) where
%%%			F is the file name
%%%			N is the number of goals
%%%		Action: write goals in the output files

writeGoalsListOfFiles([]).
writeGoalsListOfFiles([(F,N)|LFN]):-
		getAutomaticProver(AP),
		getOutputLanguage(OL),
		writeGoalsFile(F,OL,AP,1,N,RG),
		print_to_screen('\t'),
		print_to_screen('File '),
		print_to_screen(F),
		print_to_screen(' completed (total goals --> '),
		print_to_screen(RG),
		print_to_screen(').'),
		print_to_screen('\n'),
		writeGoalsListOfFiles(LFN).

%%% writeGoalsFile(in F, in OL, in AP, in CG, in NG, out NRG)
%%%		F: a file name
%%%		OL: output language
%%%		AP: the automatic prover to be used
%%%		IG: index of goals
%%%		NG: total number of goals in the file
%%%		NRG: number of real goals that have been written to the file
%%%		Action: write automatically sorted goals in the output file

writeGoalsFile(_,_,_,IG,NG,0):-
		IG > NG,
		!.
writeGoalsFile(F,OL,AP,IG,NG,NRG):-
		getGoalKey(F,IG,K),
		getGoal(K,G),
		atom_concat(AP,'.',NAP),
		atom_concat(NAP,OL,SOL),
		atom_concat('Goals/',K,K1),
		atom_concat(K1,'.adimen.',K2),
		atom_concat(K2,SOL,NK),
		open(NK,write,S),
		writeGoal(S,OL,AP,G,K,RG1),
		close(S),
		NIG is IG + 1,
		writeGoalsFile(F,OL,AP,NIG,NG,RG2),
		NRG is RG1 + RG2.

%%% writeGoal(in S, in OL, in AP, in G, in K, out NRA)
%%%		S: output stream
%%%		OL: output language
%%%		AP: the automatic prover to be used
%%%		G: goal
%%%		K: goal key
%%%		NRA: number of real goals that have been written to the file
%%%		Action: the goal is written in the output stream

% % TSTP format % %

writeGoal(S,tstp,AP,G,K,1):-
		print_to_file(S,'fof( '),
		print_to_file(S,K),
		print_to_file(S,', conjecture,'),
		print_to_file(S,'\n'),
		writeFormula(S,0,tstp,AP,1,G,_),
		!,
		print_to_file(S,').'),
		print_to_file(S,'\n'),
		print_to_file(S,'\n').

% % TPTP format % %

writeGoal(S,tptp,AP,G,K,1):-
		print_to_file(S,'input_formula( '),
		print_to_file(S,K),
		print_to_file(S,', conjecture,'),
		print_to_file(S,'\n'),
		writeFormula(S,0,tptp,AP,1,G,_),
		!,
		print_to_file(S,').'),
		print_to_file(S,'\n'),
		print_to_file(S,'\n').

% % KIF format % %

writeGoal(S,kif,_,G,_,0):-
		writeFormula(S,0,kif,_,0,G,_),
		!.

% % Error % %

writeGoal(_,L,AP,_,K,_):-
		print_to_screen('Error writting the goal '),
		print_to_screen(K),
		print_to_screen('\n'),
		print_to_screen('Language --> '),
		print_to_screen(L),
		print_to_screen('\n'),
		print_to_screen('Automatic prover --> '),
		print_to_screen(AP),
		print_to_screen('\n'),
		fail.

%%% Input-output predicates %%%

%%% print_text_goal(in T)
%%%		T: the text of an goal

print_text_goal([]).
print_text_goal([LC|T]):-
		atom_codes(L,LC),
		print_to_screen(L),
		print_to_screen('\n'),
		print_text_goal(T).
